======
game24
======

A console application to play the 24 Game (see the `Wikipedia article <https://en.wikipedia.org/wiki/24_Game>`_ for introduction)

Installation
------------

.. code-block:: bash

    $ pip install game24

Or

.. code-block:: bash

    $ python setup.py install

Usage
-----

* Play the game

.. code-block:: bash

    $ 24gameconsole

* Check solutions for a hand of cards

.. code-block:: bash

    $ 24gameconsole <integer1> <integer2> <integer3> <integer4>

* Check result for an expression (a simple calculator)

.. code-block:: bash

    $ 24gameconsole 'expression'

TODO
-----

- Add Python3 support.
- Add test cases.


License
-------

Copyright 2015 benhengx

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
